




def descr(name):
	
	descr = {
		'eta_fc': 'Umrechnungsfaktor',
		'eta_t': 'Umrechnungsfaktor für Betonfestigkeiten',
		'fcd': 'Bemessungswert der Druckfestigkeit',
		'fctd': 'Bemessungswert der Betonzugfestigkeit',
		'fsd': 'Bemessungswert der Fliessgrenze von Betonstahl',
		'mrd': 'Widerstandsmoment',
		'mrd_': 'Rissmoment',
	}
	
	return descr.get(name, '')





def sort_results(rslts):
	return [rslts[k] for k in sorted(rslts)]



class Results:
	
	def __init__(self):
		self.main_rslts = {}
		self.semi_rslts = {}
		self.resultsf = {}
	
	def add_rslt(self, name, rslt, lbl, unit, ff='', f=''):
		self.resultsf[name] = {
			'name': name,
			'standard': self.standard,
			'ff': '{} {}'.format(self.standard, ff),
			'f': f,
			'description': descr(name),
			'label': lbl,
			'result': rslt,
			'unit': unit,
			}
		

	
	def get_results(self):
		return self.resultsf
	
	def get_semi_rslts(self):
		return sort_results(self.semi_rslts)
	
	
	def sorted_results(self):
		return [self.resultsf[k] for k in sorted(self.resultsf)]
	
	def quick_results(self, pick):
		return [self.resultsf[k] for k in pick]



import unittest
from civeng.concrete.modules.bending_force import BendingForce
from civeng.concrete.params import gamma_c, eta_t, gamma_s, dm, s


class BendingForceTest(unittest.TestCase):
	
	def setUp(self):
		self.entries = {
			'beton': (3, 3),
			'gamma_c': (gamma_c, gamma_c),
			'eta_t': (eta_t, eta_t),
			'betonstahl': (0, 0),
			'gamma_s': (gamma_s, gamma_s),
			'dm_inf': (dm, dm),
			's_inf:': (s, s),
			'w': (1000, 1000),
			'h': (250, 300),
			'd_inf': (210, 260),
			}
		print('setUp executed!')
	
	def testCalculation(self):
		
		for i in range(len(self.entries['beton'])):
			entries = {}
			for k, v in self.entries.items():
				entries[k] = v[i]
			
			biegung = BendingForce(entries)
			for v in biegung.compute():
				print(v)


if __name__ == "__main__":
	unittest.main()




from setuptools import setup

setup(name='civeng',
      version='0.2.1',
      description='civil structural engineering tools',
      url='http://github.com/storborg/funniest',
      author='dutu8ure',
      author_email='dutu8ure@gmail.com',
      license='MIT',
      packages=['civeng'],
      zip_safe=False)
